@@ -45,17 +45,12 @@
 #include <dbus/dbus.h>
 
 #include "sdpd.h"
-#include "logging.h"
+#include "log.h"
 #include "manager.h"
+#include "adapter.h"
 
 static sdp_record_t *server = NULL;
 
-static uint8_t service_classes = 0x00;
-
-static uint16_t did_vendor = 0x0000;
-static uint16_t did_product = 0x0000;
-static uint16_t did_version = 0x0000;
-
 /*
  * List of version numbers supported by the SDP server.
  * Add to this list when newer versions are supported.
@@ -100,144 +95,18 @@ static void update_db_timestamp(void)
 
 static void update_svclass_list(const bdaddr_t *src)
 {
-	sdp_list_t *list = sdp_get_record_list();
-	uint8_t val = 0;
+	GSList *adapters = manager_get_adapters();
 
-	for (; list; list = list->next) {
-		sdp_record_t *rec = (sdp_record_t *) list->data;
+	for (; adapters; adapters = adapters->next) {
+		struct btd_adapter *adapter = adapters->data;
+		bdaddr_t bdaddr;
 
-		if (rec->svclass.type != SDP_UUID16)
-			continue;
+		adapter_get_address(adapter, &bdaddr);
 
-		switch (rec->svclass.value.uuid16) {
-		case DIALUP_NET_SVCLASS_ID:
-		case CIP_SVCLASS_ID:
-			val |= 0x42;	/* Telephony & Networking */
-			break;
-		case IRMC_SYNC_SVCLASS_ID:
-		case OBEX_OBJPUSH_SVCLASS_ID:
-		case OBEX_FILETRANS_SVCLASS_ID:
-		case IRMC_SYNC_CMD_SVCLASS_ID:
-		case PBAP_PSE_SVCLASS_ID:
-			val |= 0x10;	/* Object Transfer */
-			break;
-		case HEADSET_SVCLASS_ID:
-		case HANDSFREE_SVCLASS_ID:
-			val |= 0x20;	/* Audio */
-			break;
-		case CORDLESS_TELEPHONY_SVCLASS_ID:
-		case INTERCOM_SVCLASS_ID:
-		case FAX_SVCLASS_ID:
-		case SAP_SVCLASS_ID:
-		/*
-		 * Setting the telephony bit for the handsfree audio gateway
-		 * role is not required by the HFP specification, but the
-		 * Nokia 616 carkit is just plain broken! It will refuse
-		 * pairing without this bit set.
-		 */
-		case HANDSFREE_AGW_SVCLASS_ID:
-			val |= 0x40;	/* Telephony */
-			break;
-		case AUDIO_SOURCE_SVCLASS_ID:
-		case VIDEO_SOURCE_SVCLASS_ID:
-			val |= 0x08;	/* Capturing */
-			break;
-		case AUDIO_SINK_SVCLASS_ID:
-		case VIDEO_SINK_SVCLASS_ID:
-			val |= 0x04;	/* Rendering */
-			break;
-		case PANU_SVCLASS_ID:
-		case NAP_SVCLASS_ID:
-		case GN_SVCLASS_ID:
-			val |= 0x02;	/* Networking */
-			break;
-		}
+		if (bacmp(src, BDADDR_ANY) == 0 || bacmp(src, &bdaddr) == 0)
+			btd_adapter_services_updated(adapter);
 	}
 
-	SDPDBG("Service classes 0x%02x", val);
-
-	service_classes = val;
-
-	manager_update_svc(src, val);
-}
-
-uint8_t get_service_classes(const bdaddr_t *bdaddr)
-{
-	return service_classes;
-}
-
-void create_ext_inquiry_response(const char *name, uint8_t *data)
-{
-	sdp_list_t *list = sdp_get_record_list();
-	uint8_t *ptr = data;
-	uint16_t uuid[24];
-	int i, index = 0;
-
-	if (name) {
-		int len = strlen(name);
-
-		if (len > 48) {
-			len = 48;
-			ptr[1] = 0x08;
-		} else
-			ptr[1] = 0x09;
-
-		ptr[0] = len + 1;
-
-		memcpy(ptr + 2, name, len);
-
-		ptr += len + 2;
-	}
-
-	if (did_vendor != 0x0000) {
-		uint16_t source = 0x0002;
-		*ptr++ = 9;
-		*ptr++ = 0x10;
-		*ptr++ = (source & 0x00ff);
-		*ptr++ = (source & 0xff00) >> 8;
-		*ptr++ = (did_vendor & 0x00ff);
-		*ptr++ = (did_vendor & 0xff00) >> 8;
-		*ptr++ = (did_product & 0x00ff);
-		*ptr++ = (did_product & 0xff00) >> 8;
-		*ptr++ = (did_version & 0x00ff);
-		*ptr++ = (did_version & 0xff00) >> 8;
-	}
-
-	ptr[1] = 0x03;
-
-	for (; list; list = list->next) {
-		sdp_record_t *rec = (sdp_record_t *) list->data;
-
-		if (rec->svclass.type != SDP_UUID16)
-			continue;
-
-		if (rec->svclass.value.uuid16 < 0x1100)
-			continue;
-
-		if (index > 23) {
-			ptr[1] = 0x02;
-			break;
-		}
-
-		for (i = 0; i < index; i++)
-			if (uuid[i] == rec->svclass.value.uuid16)
-				break;
-
-		if (i == index - 1)
-			continue;
-
-		uuid[index++] = rec->svclass.value.uuid16;
-	}
-
-	if (index > 0) {
-		ptr[0] = (index * 2) + 1;
-		ptr += 2;
-
-		for (i = 0; i < index; i++) {
-			*ptr++ = (uuid[i] & 0x00ff);
-			*ptr++ = (uuid[i] & 0xff00) >> 8;
-		}
-	}
 }
 
 void register_public_browse_group(void)
@@ -298,8 +167,8 @@ void register_server_service(void)
 	 * to the server on command line. Now defaults to 1.0
 	 * Build the version number sequence first
 	 */
-	versions = (void **)malloc(sdpServerVnumEntries * sizeof(void *));
-	versionDTDs = (void **)malloc(sdpServerVnumEntries * sizeof(void *));
+	versions = malloc(sdpServerVnumEntries * sizeof(void *));
+	versionDTDs = malloc(sdpServerVnumEntries * sizeof(void *));
 	dtd = SDP_UINT16;
 	for (i = 0; i < sdpServerVnumEntries; i++) {
 		uint16_t *version = malloc(sizeof(uint16_t));
@@ -334,9 +203,7 @@ void register_device_id(const uint16_t vendor, const uint16_t product,
 
 	info("Adding device id record for %04x:%04x", vendor, product);
 
-	did_vendor = vendor;
-	did_product = product;
-	did_version = version;
+	btd_manager_set_did(vendor, product, version);
 
 	record->handle = sdp_next_handle();
 
@@ -390,13 +257,13 @@ int add_record_to_server(const bdaddr_t *src, sdp_record_t *rec)
 	if (rec->handle == 0xffffffff) {
 		rec->handle = sdp_next_handle();
 		if (rec->handle < 0x10000)
-			return -1;
+			return -ENOSPC;
 	} else {
 		if (sdp_record_find(rec->handle))
-			return -1;
+			return -EEXIST;
 	}
 
-	debug("Adding record with handle 0x%05x", rec->handle);
+	DBG("Adding record with handle 0x%05x", rec->handle);
 
 	sdp_record_add(src, rec);
 
@@ -416,7 +283,7 @@ int add_record_to_server(const bdaddr_t *src, sdp_record_t *rec)
 			continue;
 
 		sdp_uuid2strn((uuid_t *) pattern->data, uuid, sizeof(uuid));
-		debug("Record pattern UUID %s", uuid);
+		DBG("Record pattern UUID %s", uuid);
 	}
 
 	update_db_timestamp();
@@ -429,7 +296,7 @@ int remove_record_from_server(uint32_t handle)
 {
 	sdp_record_t *rec;
 
-	debug("Removing record with handle 0x%05x", handle);
+	DBG("Removing record with handle 0x%05x", handle);
 
 	rec = sdp_record_find(handle);
 	if (!rec)
@@ -602,7 +469,7 @@ success:
 	}
 
 	update_db_timestamp();
-	update_svclass_list(BDADDR_ANY);
+	update_svclass_list(&req->device);
 
 	/* Build a rsp buffer */
 	bt_put_unaligned(htonl(rec->handle), (uint32_t *) rsp->data);
